This is a single package that combines Heng Li's packages samtools and tabix, which are awesome but unfortunately cause lots of linker errors when linked together with C code that needs both.  It is a merge of AngieHinrichs/samtools, forked from lh3/samtools and patched to allow alternate network lib and not check EOF) and tabix-0.2.6 downloaded from samtools.sourceforge.net.  I replaced samtools' bgzf.[ch] with tabix's because tabix's seemed more recent. Had to modify some samtools files to work with updated bgzf.h.
